HostApi

Struct HostApi 

#[repr(C)]
pub struct HostApi { pub ctx: *mut c_void, pub get_var: unsafe extern "C" fn(ctx: *mut c_void, name: *const c_char) -> *const c_char, pub set_var: unsafe extern "C" fn(ctx: *mut c_void, name: *const c_char, value: *const c_char) -> i32, pub export_var: unsafe extern "C" fn(ctx: *mut c_void, name: *const c_char, value: *const c_char) -> i32, pub get_cwd: unsafe extern "C" fn(ctx: *mut c_void) -> *const c_char, pub set_cwd: unsafe extern "C" fn(ctx: *mut c_void, path: *const c_char) -> i32, pub write_stdout: unsafe extern "C" fn(ctx: *mut c_void, data: *const c_char, len: usize) -> i32, pub write_stderr: unsafe extern "C" fn(ctx: *mut c_void, data: *const c_char, len: usize) -> i32, }
API callbacks yosh provides to plugins.

ctx is an opaque pointer to yosh internals. Plugins pass it back to each callback but must not dereference or store it beyond the current call.

Fields

ctx: *mut c_voidget_var: unsafe extern "C" fn(ctx: *mut c_void, name: *const c_char) -> *const c_charset_var: unsafe extern "C" fn(ctx: *mut c_void, name: *const c_char, value: *const c_char) -> i32export_var: unsafe extern "C" fn(ctx: *mut c_void, name: *const c_char, value: *const c_char) -> i32get_cwd: unsafe extern "C" fn(ctx: *mut c_void) -> *const c_charset_cwd: unsafe extern "C" fn(ctx: *mut c_void, path: *const c_char) -> i32write_stdout: unsafe extern "C" fn(ctx: *mut c_void, data: *const c_char, len: usize) -> i32write_stderr: unsafe extern "C" fn(ctx: *mut c_void, data: *const c_char, len: usize) -> i32